@@ -13,7 +13,7 @@ REGIONS = {u'ad': u'\u0b85\u0ba3\u0bcd\u0b9f\u0bcb\u0bb0\u0bbe',
  u'at': u'\u0b86\u0bb8\u0bcd\u0b9f\u0bcd\u0bb0\u0bbf\u0baf\u0bbe',
  u'au': u'\u0b86\u0bb8\u0bcd\u0ba4\u0bbf\u0bb0\u0bc7\u0bb2\u0bbf\u0baf\u0bbe',
  u'aw': u'\u0b85\u0bb0\u0bc2\u0baa\u0bbe',
- u'ax': u'\\u00c5land \u0ba4\u0bc0\u0bb5\u0bc1\u0b95\u0bb3\u0bcd',
+ u'ax': u'\xc5land \u0ba4\u0bc0\u0bb5\u0bc1\u0b95\u0bb3\u0bcd',
  u'az': u'\u0b85\u0b9a\u0bb0\u0bcd\u0baa\u0bc8\u0b9c\u0bbe\u0ba9\u0bcd',
  u'ba': u'\u0baa\u0bcb\u0bb8\u0bcd\u0ba9\u0bbf\u0baf\u0bbe \u0bae\u0bb1\u0bcd\u0bb1\u0bc1\u0bae\u0bcd \u0bb9\u0bc7\u0bb0\u0bcd\u0b9a\u0bbf\u0b95\u0bcb\u0ba9\u0bbf\u0baf\u0bbe',
  u'bb': u'\u0baa\u0bbe\u0bb0\u0bcd\u0baa\u0ba4\u0bbe\u0bb8\u0bcd',
@@ -24,7 +24,7 @@ REGIONS = {u'ad': u'\u0b85\u0ba3\u0bcd\u0b9f\u0bcb\u0bb0\u0bbe',
  u'bh': u'\u0baa\u0bc6\u0bb9\u0bb0\u0bc8\u0ba9\u0bcd',
  u'bi': u'\u0baa\u0bcd\u0bb0\u0bc2\u0ba3\u0bcd\u0ba4\u0bc0',
  u'bj': u'\u0baa\u0bbf\u0ba9\u0bbf\u0ba9\u0bcd',
- u'bl': u'\u0b9a\u0bc6\u0baf\u0bbf\u0ba3\u0bcd\u0b9f\u0bcd \u0baa\u0bbe\u0bb0\u0bcd\u0ba4\u0bcd\\u00e9lemy',
+ u'bl': u'\u0b9a\u0bc6\u0baf\u0bbf\u0ba3\u0bcd\u0b9f\u0bcd \u0baa\u0bbe\u0bb0\u0bcd\u0ba4\u0bcd\xe9lemy',
  u'bm': u'\u0baa\u0bb0\u0bcd\u0bae\u0bc1\u0b9f\u0bbe',
  u'bn': u'\u0baa\u0bcd\u0bb0\u0bc2\u0ba9\u0bc8 \u0ba4\u0bb0\u0bc1\u0b9a\u0bb2\u0bbe\u0bae\u0bcd',
  u'bo': u'\u0baa\u0bca\u0bb2\u0bbf\u0bb5\u0bbf\u0baf\u0bbe',
